'''
Copyright (c) 2022 Marco Diniz Sousa

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

'''

from antlr4_verilog.systemverilog.SystemVerilogLexer import SystemVerilogLexer
from antlr4_verilog.systemverilog.SystemVerilogParser import SystemVerilogParser
from antlr4_verilog.systemverilog.SystemVerilogParserListener import SystemVerilogParserListener
from antlr4_verilog.systemverilog.SystemVerilogParserVisitor import SystemVerilogParserVisitor
